agenttools.InspectionAgent
==========================

.. abjad-lineage:: abjad.tools.agenttools.InspectionAgent.InspectionAgent

.. autoclass:: abjad.tools.agenttools.InspectionAgent.InspectionAgent

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.client
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_annotation
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_badly_formed_components
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_components
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_contents
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_descendants
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_duration
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_effective
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_effective_staff
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_grace_container
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_grace_containers
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_indicator
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_indicators
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_leaf
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_lineage
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_logical_tie
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_markup
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_parentage
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_sounding_pitch
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_sounding_pitches
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_spanner
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_spanners
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_timespan
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_vertical_moment
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_vertical_moment_at
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.has_effective_indicator
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.has_indicator
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.is_bar_line_crossing
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.is_well_formed
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.report_modifications
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.tabulate_well_formedness_violations
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.__eq__
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.__format__
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.__hash__
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.__ne__
      ~abjad.tools.agenttools.InspectionAgent.InspectionAgent.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.client
   :noindex:

Methods
-------

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_annotation
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_badly_formed_components
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_components
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_contents
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_descendants
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_duration
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_effective
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_effective_staff
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_grace_container
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_grace_containers
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_indicator
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_indicators
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_leaf
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_lineage
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_logical_tie
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_markup
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_parentage
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_sounding_pitch
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_sounding_pitches
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_spanner
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_spanners
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_timespan
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_vertical_moment
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.get_vertical_moment_at
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.has_effective_indicator
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.has_indicator
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.is_bar_line_crossing
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.is_well_formed
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.report_modifications
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.tabulate_well_formedness_violations
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.__eq__
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.__format__
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.__hash__
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.__ne__
   :noindex:

.. automethod:: abjad.tools.agenttools.InspectionAgent.InspectionAgent.__repr__
   :noindex:
